# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
import filer.fields.image
import jsonfield.fields


class Migration(migrations.Migration):

    dependencies = [
        ('filer', '0002_auto_20150606_2003'),
        ('cms', '0013_urlconfrevision'),
    ]

    operations = [
        migrations.CreateModel(
            name='ImagePlugin',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(to='cms.CMSPlugin', parent_link=True, primary_key=True, auto_created=True, serialize=False)),
                ('glossary', jsonfield.fields.JSONField()),
                ('image', filer.fields.image.FilerImageField(null=True, blank=True, to='filer.Image', verbose_name='image', default=None)),
            ],
            options={
                'verbose_name_plural': 'responsive filer images',
                'verbose_name': 'responsive filer image',
            },
            bases=('cms.cmsplugin',),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.core.exceptions import ImproperlyConfigured
from django.db import models
from django.utils.translation import ugettext_lazy as _
from cms.models import CMSPlugin
from filer.fields.image import FilerImageField
from jsonfield.fields import JSONField

from .conf import settings

class ImagePluginBase(CMSPlugin):
    glossary = JSONField(default={})

    class Meta:
        abstract = True

class ImagePlugin(ImagePluginBase):
    image = FilerImageField(null=True, blank=True, default=None, verbose_name=_("image"))

    class Meta:
        verbose_name = _('responsive filer image')
        verbose_name_plural = _('responsive filer images')

    def get_style_name(self):
        return self.glossary.get('style',
            settings.DJANGOCMS_RESPONSIVE_IMAGE_IMAGE_DEFAULT_STYLE)

    def get_style(self):
        try:
            return settings.DJANGOCMS_RESPONSIVE_IMAGE_IMAGE_STYLE_CHOICES[
                self.get_style_name()]
        except KeyError:
            error_msg = ("ResponsiveImage style {0} is used by plugin {1}, "
                         "but not defined in the settings.").format(
                            self.get_style_name(), self)
            raise ImproperlyConfigured(error_msg)

    def __str__(self):
        return self.image.label




# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.template.loader import select_template
from django.utils.translation import ugettext_lazy as _
from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool

from . import models
from .conf import settings
from .forms import ResponsiveImageForm

class ResponsiveImagePlugin(CMSPluginBase):
    module = 'Filer'
    model = models.ImagePlugin
    name = _('Responsive Image')
    form = ResponsiveImageForm
    TEMPLATE_NAME = 'djangocms_responsive_image/plugins/image/{0}.html'
    render_template = TEMPLATE_NAME.format('default')

    def render(self, context, instance, placeholder):
        style_name = instance.get_style_name()
        style = instance.get_style()
        self.render_template = select_template((
            self.TEMPLATE_NAME.format(style_name),
            self.TEMPLATE_NAME.format('default'))
        )
        srcset = []
        for src in style['srcset']:
            if instance.image.width > src[0] and instance.image.height > src[1]:
                srcset.append(src)
            else:
                srcset.append((instance.image.width, instance.image.height))
                break
        context.update({
            'srcset': srcset,
            'sizes': style.get('sizes'),
            'default_size': style['default_size'],
            'style': style_name,
            'instance': instance,
            'placeholder': placeholder
        })
        return context

plugin_pool.register_plugin(ResponsiveImagePlugin)




# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
import jsonfield.fields


class Migration(migrations.Migration):

    dependencies = [
        ('djangocms_responsive_image', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='imageplugin',
            name='glossary',
            field=jsonfield.fields.JSONField(default={}),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.conf import settings
from django.utils.translation import ugettext_lazy as _

from appconf import AppConf

class ResponsiveImageAppConf(AppConf):
    IMAGE_STYLE_CHOICES = {
        'default': {
            'name': _('default'),
            'srcset': ((300, 0), (800, 0), (1600, 0), (2000, 0)),
            'sizes': None,
            'default_size': (1600, 0),
        },
    }
    IMAGE_DEFAULT_STYLE = 'default'




from setuptools import setup, find_packages
setup(
    name = 'djangocms-responsive-image',
    packages = find_packages(exclude=('tests', 'tests.*')),
    include_package_data=True,
    license='MIT License',
    version = '0.0.11',
    description = 'Django CMS plugin implementing html5 responsive images',
    author = 'Fabian Lehner',
    author_email = 'fl@makonis.net',
    url = 'https://github.com/febsn/djangocms-responsive-image',
    download_url = 'https://github.com/febsn/djangocms-responsive-image/tarball/0.0.11',
    install_requires = [
       'django-filer>=1.0.4',
       'jsonfield>=1.0.3',
       'django-appconf>=1.0.1',
    ],
    keywords = ['responsive', 'image', 'django'],
    classifiers = [],
)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django import forms

from .models import ImagePlugin
from .conf import settings

class GlossaryFormBase(forms.ModelForm):

    glossary_fields = tuple()

    def __init__(self, data=None, files=None, **kwargs):
        # set values for glossary form fields
        # values from initial overrule those from instance
        instance = kwargs.pop('instance', None)
        initial = kwargs.pop('initial', {})
        if instance and data is None:
            for field in self.glossary_fields:
                try:
                    initial[field] = initial.get(field, None) or instance.glossary[field]
                except KeyError:
                    pass
        return super(GlossaryFormBase, self).__init__(data=data, files=files, 
            instance=instance, initial=initial, **kwargs)

    def save(self, commit=True):
        if not commit:
            for field in self.glossary_fields:
                self.instance.glossary[field] = self.cleaned_data[field]
        return super(GlossaryFormBase, self).save(commit=commit)

class ResponsiveImageForm(GlossaryFormBase):
    STYLE_CHOICES = [
        (key, value['name'])
        for key, value
        in settings.DJANGOCMS_RESPONSIVE_IMAGE_IMAGE_STYLE_CHOICES.items()
    ]
    style = forms.ChoiceField(
        choices=STYLE_CHOICES)
    caption = forms.CharField(max_length=512, required=False)
    alt = forms.CharField(max_length=512, required=False)

    glossary_fields = ('style', 'caption', 'alt',)
    class Meta:
        model = ImagePlugin
        fields = ('image', )

